diff Applications/Samples/build-wasm.sh @ 518:40bb5eb247a5 bgo-commands-codegen

Reverted a couple of files to AM version (wrong changes on my end)
author Benjamin Golinvaux <bgo@osimis.io>
date Tue, 12 Mar 2019 09:19:06 +0100
parents 801d2697a1b1
children f417a0ae282b
line wrap: on
line diff
--- a/Applications/Samples/build-wasm.sh	Tue Mar 12 08:51:35 2019 +0100
+++ b/Applications/Samples/build-wasm.sh	Tue Mar 12 09:19:06 2019 +0100
@@ -1,15 +1,16 @@
 #!/bin/bash
 #
 # usage:
 # to build all targets:
 # ./build-wasm.sh
 #
-# to build a single target:
-# ./build-wasm.sh OrthancStoneSingleFrameEditor
+# to build a single target in release:
+# ./build-wasm.sh OrthancStoneSingleFrameEditor Release
 
 set -e
 
 target=${1:-all}
+buildType=${2:-Debug}
 
 currentDir=$(pwd)
 samplesRootDir=$(pwd)
@@ -18,16 +19,9 @@
 cd $samplesRootDir/build-wasm
 
 source ~/apps/emsdk/emsdk_env.sh
-cmake -G Ninja -DCMAKE_TOOLCHAIN_FILE=${EMSCRIPTEN}/cmake/Modules/Platform/Emscripten.cmake \
-  -DCMAKE_BUILD_TYPE=Release \
-  -DSTONE_SOURCES_DIR=$currentDir/../../../orthanc-stone \
-  -DORTHANC_FRAMEWORK_SOURCE=path \
-  -DORTHANC_FRAMEWORK_ROOT=$currentDir/../../../orthanc \
-  -DALLOW_DOWNLOADS=ON .. \
-  -DENABLE_WASM=ON
-
+cmake -G Ninja -DCMAKE_TOOLCHAIN_FILE=${EMSCRIPTEN}/cmake/Modules/Platform/Emscripten.cmake -DCMAKE_BUILD_TYPE=$buildType -DSTONE_SOURCES_DIR=$currentDir/../../../orthanc-stone -DORTHANC_FRAMEWORK_SOURCE=path -DORTHANC_FRAMEWORK_ROOT=$currentDir/../../../orthanc -DALLOW_DOWNLOADS=ON .. -DENABLE_WASM=ON
 ninja $target
 
 echo "-- building the web application -- "
 cd $currentDir
-./build-web.sh
+./build-web.sh
\ No newline at end of file
@@ -1,15 +1,16 @@
 #
 # usage:
-# to build all targets:
+# to build all targets in Debug:
 # ./build-wasm.sh
 #